/*******************************************************************************
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   David Knibb               initial implementation      
 *   Gordon Hutchison          initial implementation      
 *******************************************************************************/

package org.dek.tooltip;

/**
 * This aspect affects any object executing a setToolTipText method.
 * A stackTrace will be appended to the tooltip, 
 * which may help to show where the control was created.
 */
public aspect TooltipAspect {
	
	void around (Object tooltippee, String text) :
		this(tooltippee) &&
		execution (* setToolTipText(..)) &&
		args(text) &&
		!within(TooltipAspect+){
		
			Exception e = new Exception();
			StackTraceElement[] st = e.getStackTrace();
			StringBuffer result = new StringBuffer(text+"\n");
			int max = st.length < 10 ? st.length : 10;		//limit the number of lines of stack trace. No real need for this but it keeps the output a bit neater.
			for(int i=0; i<max; i++){
				result.append(st[i]+"\n");
			}
			proceed (tooltippee, new String(result));
		}

}
